//
//  CheckButton.swift
//  CheckboxApp
//
//  Created by Travis on 2018-07-24.
//  Copyright © 2018 logicandform. All rights reserved.
//

import UIKit

class CheckBoxButton: UIButton {
    private var checkBoxView: CheckBoxView!
    private var checkBoxForward: CheckBoxAnimationForwardTimeline!
    private var checkBoxReverse: CheckBoxAnimationReverseTimeline!
    private var backgroundView: BackgroundView!
    private var backgroundViewForward: BackgroundAnimationForwardTimeline!
    private var backgroundViewReverse: BackgroundAnimationReverseTimeline!

    override func awakeFromNib() {
        super.awakeFromNib()
        styleButton()
        createCheckBox()
        createBackground()
        createTimelines()
        addTarget(self, action: #selector(toggle), for: .touchUpInside)
    }

    func styleButton() {
        titleLabel?.font = UIFont(name: "SFUIText-Medium", size: 14)
        titleLabel?.textColor = UIColor(red: 0.149, green: 0.149, blue: 0.149, alpha: 1)
        titleLabel?.textAlignment = .left
        contentHorizontalAlignment = .left
        titleEdgeInsets = UIEdgeInsetsMake(0.0, 49, 0.0, 0.0)
    }

    @objc func toggle() {
        isSelected = !isSelected
        if isSelected {
            checkBoxForward.animate()
            backgroundViewForward.animate()
        } else {
            checkBoxReverse.animate()
            backgroundViewReverse.animate()
        }
    }

    func createCheckBox() {
        checkBoxView = CheckBoxView(frame: CGRect(x: 7, y: 8, width: 26, height: 26))
        addSubview(checkBoxView)
    }

    func createTimelines() {
        checkBoxForward = CheckBoxAnimationForwardTimeline(view: checkBoxView)
        checkBoxReverse = CheckBoxAnimationReverseTimeline(view: checkBoxView)
        backgroundViewForward = BackgroundAnimationForwardTimeline(view: backgroundView)
        backgroundViewReverse = BackgroundAnimationReverseTimeline(view: backgroundView)
    }

    func createBackground() {
        backgroundView = BackgroundView(frame: self.bounds)
        backgroundView.isUserInteractionEnabled = false
        addSubview(backgroundView)
        sendSubview(toBack: backgroundView)
    }
}
